@@ -40,6 +40,9 @@ class BedLineIterator(object):
         while line[:5] in {'brows', 'track'}:
             line = next(self.iterator)
             line_no += 1
+        if line.startswith('chromosome'):
+            line = next(self.iterator)
+            line_no += 1
         self.iterator = chain([line], self.iterator)
         self.line_no = line_no
         return hdrs
@@ -47,10 +50,16 @@ class BedLineIterator(object):
     @staticmethod
     def parse_line(line):
         parts = line.rstrip('\r\n').split('\t')
-        parts[1] = int(parts[1]) - 1
-        parts[2] = int(parts[2])
-        parts.extend(None for i in range(6 - len(parts)))
-        return BedLine(*parts)
+        name = parts[3] if len(parts) > 3 else ''
+        score = parts[4] if len(parts) > 4 else ''
+        strand = parts[5] if len(parts) > 5 else '+'
+        return Interval(int(parts[1]) - 1, int(parts[2]),
+                        chromosome=parts[0],
+                        strand=strand,
+                        data={
+                            'name': name,
+                            'score': score
+                        })
 
 
 class BedEntryIterator(BedLineIterator):
@@ -61,9 +70,12 @@ class BedEntryIterator(BedLineIterator):
         line = next(self.iterator)
         self.line_no += 1
         if line == '':
-            return()
+            raise StopIteration
         return self.parse_entry(self.parse_line(line))
 
     @staticmethod
     def parse_entry(line):
-        return BedEntry(Interval(line.chr, line.start, line.stop, strand=line.strand), line.name, line.score)
+        return Interval(line.start, line.stop, strand=line.strand, data={
+            'name': line.data['name'],
+            'score': line.data['score']
+        })
